@@ -150,6 +150,12 @@ class Configuration:
         else:
             return "https://dev.cognicept.systems/api/v1/"
 
+    def get_field(object, field_name):
+        if field_name in object.config:
+            return object.config[field_name]
+        else:
+            raise KeyError(field_name)
+        
     def interpret_bool_input(object,input_string):
         if(input_string == 'Y'):
             return True
