@@ -9,7 +9,8 @@ import pkg_resources
 
 from cogniceptshell.configuration import Configuration
 from cogniceptshell.agent_life_cycle import AgentLifeCycle
-
+from cogniceptshell.rosbag_record import RosbagRecord
+from cogniceptshell.pusher import Pusher
 
 
 def main():
@@ -28,6 +29,8 @@ def main():
     parser_restart = subparsers.add_parser('restart', help='Restart Cognicept agents')
     parser_stop = subparsers.add_parser('stop', help='Stops Cognicept agents')
     parser_orbitty = subparsers.add_parser('orbitty', help='Run Orbitty')
+    parser_record = subparsers.add_parser('record', help='Manages rosbag recording')
+    parser_push = subparsers.add_parser('push', help='Pushes stuff to Cognicept cloud')
 
     local_cfg = Configuration()
     DEFAULT_PATH = "~/.cognicept/"
@@ -57,6 +60,19 @@ def main():
     parser_orbitty.set_defaults(func=agent_lifetime.run_orbitty)
     parser_orbitty.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
+    record_session = RosbagRecord()
+    parser_record.set_defaults(func=record_session.record)
+    parser_record.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
+    parser_record.add_argument('--start', help='Start rosbag recording session. Provide topics to record separated by spaces. e.g. cognicept record --start rosout odom', nargs='+')
+    parser_record.add_argument('--stop', help='Stop rosbag recording session', action='store_true')
+    parser_record.add_argument('--pause', help='Pause rosbag recording session', action='store_true')
+    parser_record.add_argument('--resume', help='Resume rosbag recording session', action='store_true')
+    parser_record.add_argument('--status', help='Get current recording session status', action='store_true')
+
+    pusher_instance = Pusher()
+    parser_push.set_defaults(func=pusher_instance.push)
+    parser_push.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
+    parser_push.add_argument('--bag', help='Pushes rosbag to the configured S3 bucket. Set to BAG to latest to upload latest bag')
     # Parse the arguments
     args = parser.parse_args()
 
